from ase import Atoms
from ase.io import read, write
from ase.optimize import BFGS
from ase.calculators.vasp import Vasp
import os

# Load your Germanium structure (you can replace this with your file path)
atoms = read('POSCAR', format='vasp')

# Set up the VASP calculator with your specific settings
calc = Vasp(
        command='srun vasp_std',
        setups={'Ge':'_d'},
        gga    = 'PE',
    encut=500, 
    kspacing=0.15, 
    sigma=0.05, 
    ediff=1e-5, 
    ibrion=2, 
    nsw=100, 
    isif=2, 
    ismear=0, 
    ncore=12, 
    kgamma=True, 
    lasph=True, 
    lcharg=False, 
    lwave=False
)
'''
calc = Vasp(
        command='srun vasp_std',
        setups={'Ge':'_d'},   
        prec = "Accurate",
            ediff = 1E-5,
            gga = 'PE',
            gamma = True)
'''
# Attach the calculator to the atoms object
#atoms.set_calculator(calc)
atoms.calc = calc
#atoms.get_potential_energy()
# Initialize the optimizer with BFGSLineSearch and set the convergence criterion for forces
optimizer = BFGS(atoms)
optimizer.run(fmax=0.5)

# Optionally, save the final optimized structure
#write('POSCAR-opt', atoms, format='vasp')

